@@ -18,8 +18,8 @@ define('MAIN_MENU_EDIT_FILE_BTN', "Edit File");
 define('MAIN_MENU_MENUS_HEADING', "MENUS");
 define('MAIN_MENU_EDIT_MENUS_BTN', "Edit Menus");
 define('MAIN_MENU_MANAGE_MENUS_BTN', "Manage Menu Assignments");
-define('MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN', "Edit CSS-Menu Parameters");
-define('MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN', "Edit CSS-Menu Styles");
+define('MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN', "Edit Menu Parameters");
+define('MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN', "Edit Menu Styles");
 define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN', "Edit JS-Menu Parameters");
 define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN_ALT', "Edit JavaScript-Menu Parameters");
 define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN', "Edit JS-Menu Styles");
@@ -37,7 +37,7 @@ define('MAIN_MENU_DELETE_PAGE_BTN', "Delete Page or Blog");
 define('MAIN_MENU_COPY_RENAME_BTN', "Copy or Rename Pages");
 define('MAIN_MENU_RESTORE_BTN', "Restore Page");
 define('MAIN_MENU_ADD_PLUGIN_TO_PAGE_BTN', "Install Plugin Into Page");
-define('MAIN_MENU_MANAGE_PAGE_ACCESS_BTN', "Manage Page Access");
+define('MAIN_MENU_MANAGE_PAGE_ACCESS_BTN', "Manage Page Access &amp; Users");
 define('MAIN_MENU_MANAGE_PAGE_ATTRIBUTES', "Manage Page Attributes");
 define('MAIN_MENU_SITE_MANAGEMENT_HEADING', "SITE MANAGEMENT");
 define('MAIN_MENU_RERUN_WIZARD_BTN', "Re-run Wizard");
@@ -136,6 +136,7 @@ define('EDITOR_SEE_FILE', "See File");
 define('EDITOR_CLEAR', "Clear");
 define('EDITOR_OPTIMIZE_IMAGES', "Optimize Images");
 define('EDITOR_RESET_IMAGES', "Reset Images");
+define('EDITOR_BACK_TO_SELECT', "Back to Select");
 define('EDITOR_EDIT_STYLES', "Edit Styles");
 // Console Text:
 define('EDITOR_PAGE_NAME', "Page Name");
@@ -168,16 +169,16 @@ define('EDITOR_FILE_BLANK_ERR', "File name cannot be blank. Please enter a file
 define('EDITOR_FOLDER_BLANK_ERR', "Folder name cannot be blank. Please enter a folder name and try again.");
 define('EDITOR_HEAD_BLANK_ERR', "Head name cannot be blank. Please enter a head name and try again.");
 define('EDITOR_PAGE_ALREADY_EXISTS_1_ERR', "Page");
-define('EDITOR_PAGE_ALREADY_EXISTS_2_ERR', "already exists. Please go back to the main menu to copy and rename your pages.");
+define('EDITOR_PAGE_ALREADY_EXISTS_2_ERR', "already exists. Please go back to PAGE MANAGEMENT/Copy or Rename Pages to copy and rename your pages.");
 define('EDITOR_AREA_ALREADY_EXISTS_1_ERR', "Border area");
-define('EDITOR_AREA_ALREADY_EXISTS_2_ERR', "already exists. Please go back to the main menu to manage border areas.");
+define('EDITOR_AREA_ALREADY_EXISTS_2_ERR', "already exists. Please go back to Manage Border Areas/Manage Custom Border Areas to manage border areas.");
 define('EDITOR_FILE_ALREADY_EXISTS_1_ERR', "File");
-define('EDITOR_FILE_ALREADY_EXISTS_2_ERR', "already exists. Please go back to the main menu to copy and rename your files.");
+define('EDITOR_FILE_ALREADY_EXISTS_2_ERR', "already exists. Please go back to Manage Images to copy and rename your files.");
 define('EDITOR_FOLDER_ALREADY_EXISTS_1_ERR', "Folder");
 define('EDITOR_FOLDER_ALREADY_EXISTS_2_ERR', "already exists.");
 define('EDITOR_ERROR_CREATING_FOLDER_ERR', "Error: Could not create folder.");
 define('EDITOR_HEAD_ALREADY_EXISTS_1_ERR', "Head");
-define('EDITOR_HEAD_ALREADY_EXISTS_2_ERR', "already exists. Please go back to the main menu to copy and rename your heads.");
+define('EDITOR_HEAD_ALREADY_EXISTS_2_ERR', "already exists. Please go back to Manage Head Code/Manage Custom Head Code to copy and rename your heads.");
 define('EDITOR_DELETE_BLOG_CONFIRM_1_MSG', "Are you sure you want to delete <b>blog id</b>");
 define('EDITOR_DELETE_BLOG_CONFIRM_2_MSG', "?");
 define('EDITOR_DELETE_AREA_CONFIRM_1_MSG', "Are you sure you want to delete the");
@@ -196,18 +197,26 @@ define('CREATE_PAGE_SELECT_HEADING', "Create Page");
 define('CREATE_PAGE_SELECT_ENTER_PAGE_NAME_BTN', "Enter Name of Page");
 define('CREATE_PAGE_SELECT_ADD_PLUGIN_BTN', "Add Plugin");
 define('CREATE_PAGE_SELECT_SELECT_LAYOUT_BTN', "Select Layout");
+define('GET_MORE_PLUGINS_BTN', "Get More Plugins");
+// Console Text:
+define('CREATE_PAGE_SELECT_CREATE_PLUGIN_GROUP', "Create all plugin pages for this plugin group");
 // Popup Messages:
 define('CREATE_PAGE_SELECT_CREATING_A_PAGE', "Creating a Page");
 define('CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT', "Selecting Page Layout");
 define('CREATE_PAGE_SELECT_HELPFUL_TIPS', "Helpful Tips");
+define('CREATE_PAGE_SELECT_ALREADY_EXISTS_ERR', "already exists. Please enter a different page name.");
+define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "There are no plugins under the category");
+define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Click on");
+define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "to locate a plugin in that category.");
 
-///////////////////////// Create Page Select /////////////////////////
+///////////////////////// Create Page /////////////////////////
 // Console Text:
 define('CREATE_PAGE_PAGE_NAME_BLANK_1_ERR', "Oops! You forgot to enter a page name.");
 define('CREATE_PAGE_PAGE_NAME_BLANK_2_ERR', "and enter a page name.");
 define('CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR', "to enter a different page name.");
 define('CREATE_PAGE_DEFAULT_CONTENT', "Enter your content here.");
 
+
 ///////////////////////// Manage Border Area Select /////////////////////////
 // Buttons:
 define('EDIT_BORDER_AREA_SELECT_HEADING', "Edit Border Areas");
@@ -217,12 +226,8 @@ define('MANAGE_BORDER_AREA_BTN', "Manage Custom Border Areas");
 ///////////////////////// Manage Border Areas /////////////////////////
 // Buttons:
 define('MANAGE_CUSTOM_BORDER_AREA_HEADING', "Manage Custom Border Areas");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_RIGHT_BTN', "Add Another Right Area");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_LEFT_BTN', "Add Another Left Area");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_TOP_BTN', "Add Another Top Area");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_BOTTOM_BTN', "Add Another Bottom Area");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_HEADER_BTN', "Add Another Header Area");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_FOOTER_BTN', "Add Another Footer Area");
+define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA_BTN', "Add Another Border Area");
+define('MANAGE_CUSTOM_BORDER_AREA_BACK_BTN', "Back to Manage Border Areas");
 // Console Text:
 define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA', "Add Border Area");
 define('MANAGE_CUSTOM_BORDER_AREA_ASSIGN_AREA', "Assign Border Area to Page");
@@ -231,7 +236,6 @@ define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA', "Delete Border Area");
 define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA_SELECT', "Select border area to rename");
 define('MANAGE_CUSTOM_BORDER_AREA_NEW_NAME', "New name");
 define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_SELECT', "Select  border area  to delete");
-define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA', "Add Border Area");
 // Popup Messages:
 define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_1_MSG', "Are you sure you want to delete the");
 define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_2_MSG', "area?");
@@ -279,6 +283,7 @@ define('EDIT_MENU_ITEMS_ITEM_TEXT', "Item Text");
 define('EDIT_MENU_ITEMS_NESTING_LEVEL', "Nesting Level");
 define('EDIT_MENU_ITEMS_URL', "URL");
 define('EDIT_MENU_ITEMS_TARGET_WINDOW', "Target Window");
+define('EDIT_MENU_ITEMS_MEGA_MENU', "Mega Menu");
 define('EDIT_MENU_ITEMS_TOP_LEVEL', "Top Level");
 define('EDIT_MENU_ITEMS_1ST_SUB_LEVEL', "1st Sub Level");
 define('EDIT_MENU_ITEMS_2ND_SUB_LEVEL', "2nd Sub Level");
@@ -302,6 +307,7 @@ define('EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG', "Menu items updated");
 define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG', "Updating menu items...");
 define('EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG', "Retrieving menu items...");
 define('EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG', "Your changes have not been saved. Do you want to save your changes before returning to the main menu?");
+define('EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG', "You have new item which has not been saved.  Please save that item before adding a new one.");
 
 ///////////////////////// Manage Menu Assignments /////////////////////////
 // Buttons:
@@ -339,11 +345,17 @@ define('EDIT_CSS_MENU_PARAMETERS_VARIABLE_WIDTH', "(variable width)");
 define('EDIT_CSS_MENU_PARAMETERS_MENU_WIDTH', "Menu Width");
 define('EDIT_CSS_MENU_PARAMETERS_SPECIAL_NOTE', "Note: Selecting any of the above locations does not assign menu to one of these areas. It merely highlights this form with the typical settings for the selected area.");
 define('EDIT_CSS_MENU_PARAMETERS_ITEM_SIZE_PADDING', "Menu Item Size and Padding");
-define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_POSITIONING', "Sub Menu Positioning");
+define('EDIT_CSS_MENU_PARAMETERS_SUB_1_MENU_POSITIONING', "Sub Menu 1 Layout and Positioning");
+define('EDIT_CSS_MENU_PARAMETERS_SUB_2_MENU_POSITIONING', "Sub Menu 2 Layout and Positioning");
 define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_TOP', "Offset from Top");
 define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_LEFT', "Offset from Left");
 define('EDIT_CSS_MENU_PARAMETERS_COLLAPSE_EXPAND', "Collapse and Expand");
-define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_SIZE_PADDING', "Sub Menu Item Size and Padding");
+define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_1_SIZE_PADDING', "Sub Menu 1 Item Size and Padding");
+define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_2_SIZE_PADDING', "Sub Menu 2 Item Size and Padding");
+define('EDIT_CSS_MENU_PARAMETERS_ITEM_SPACING', "Item Spacing");
+define('EDIT_CSS_MENU_PARAMETERS_LATCH_EXPANDED_ON_DOWN', "Latch Expanded Subs on Item Down");
+define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Base Z-Index");
+// Popup Messages:
 define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU_MSG', "Please select a menu to setup.");
 
 ///////////////////////// Edit CSS Menu Styles /////////////////////////
@@ -357,16 +369,19 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_FONT', "Sub Level 2 Font");
 define('EDIT_CSS_MENU_STYLES_COLORS_BACKGROUND', "Colors and Background");
 define('EDIT_CSS_MENU_STYLES_NORMAL_MOUSE_OUT', "Normal (mouse out)");
 define('EDIT_CSS_MENU_STYLES_HOVER_MOUSE_OVER', "Hover (mouse over)");
+define('EDIT_CSS_MENU_STYLES_DOWN', "Down (button down)");
 define('EDIT_CSS_MENU_STYLES_ACTIVE_MOUSE_CLICK', "Active (mouse click)");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_TEXT_COLOR', "Top Level Text Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_TEXT_COLOR', "Sub Level 1 Text Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "Sub Level 2 Text Color");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Level Background Color");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "Sub Level Background Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BACKGROUND_COLOR', "Sub Level 1 Background Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BACKGROUND_COLOR', "Sub Level 2 Background Color");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Level Block Border Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "Sub Level Block Border Color");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Level Item Border Color");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "Sub Level Item Border Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_ITEM_BORDER_COLOR', "Sub Level 1 Item Border Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_ITEM_BORDER_COLOR', "Sub Level 2 Item Border Color");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "T<br>o<br>p");
 define('EDIT_CSS_MENU_STYLES_BOTTOM_BORDER_VERTICAL', "B<br>o<br>t<br>t<br>o<br>m");
 define('EDIT_CSS_MENU_STYLES_LEFT_BORDER_VERTICAL', "L<br>e<br>f<br>t");
@@ -375,10 +390,17 @@ define('EDIT_CSS_MENU_STYLES_UNDERLINE_NOTE', "Link-underline will be forced to
 define('EDIT_CSS_MENU_STYLES_SAME_AS_TOP_LEVEL_NOTE', "(same as top level)");
 define('EDIT_CSS_MENU_STYLES_SAME_AS_NORMAL_NOTE', "(same as normal)");
 define('EDIT_CSS_MENU_STYLES_SELECT_MENU_MSG', "Please select a menu to style.");
+define('EDIT_CSS_MENU_STYLES_OMIT_ADJACENT_BORDERS', "O<br>m<br>i<br>t<br><br>A<br>d<br>j<br>a<br>c<br>e<br>n<br>t<br><br>B<br>o<br>r<br>d<br>e<br>r<br>s");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1', "Sub Level 1");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2', "Sub Level 2");
+define('EDIT_CSS_MENU_STYLES_SHADOW_COLOR', "Shadow Color");
+define('EDIT_CSS_MENU_STYLES_HOVER_ON_DOWN', "Hover on Down");
 // Popup Messages:
 define('EDIT_CSS_MENU_STYLES_LETTER_SPACING_MSG', "You have selected <b>Normal</b>, <b>Initial</b> or <b>Inherit</b> for your letter spacing, yet you have a number set for letter spacing. Note that the number you have selected will be ignored.  If you want to set a letter spacing, choose <b>px</b> instead.");
 define('EDIT_CSS_MENU_STYLES_SAVE_SUCCESS_MSG', "Your menu styles have been saved.");
 define('EDIT_CSS_MENU_STYLES_SAVE_FAIL_ERR', "There was an error saving your menu styles.");
+define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_1', "CSS menu parameters have not been set. Please click");
+define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_2', "to setup the CSS menu parameters");
 
 ///////////////////////// Edit JS Menu Parameters /////////////////////////
 // Buttons:
@@ -415,9 +437,10 @@ define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "Please select a menu to style.");
 ///////////////////////// Edit CSS Select /////////////////////////
 // Buttons:
 define('EDIT_CSS_SELECT_HEADING', "Edit Styles");
-define('EDIT_CSS_SELECT_CUSTOM_STYLES_BTN', "Custom Styles");
-define('EDIT_CSS_SELECT_CUSTOM_MOBILE_STYLES_BTN', "Custom Mobile Styles");
 define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "Copy Style Sheet to Mobile");
+define('COPY_STYLE_TO_MOBILE_BACK_TO_EDIT_CSS_SELECT_BTN', "Back to Edit Styles Select");
+define('EDIT_STYLE_SHEET_ATT_BTN', "Manage Style Sheet Attributes");
+// Console Text:
 define('COPY_STYLE_TO_MOBILE_NOTE', "This function is for initializing the mobile styles with the analogous desktop styles once you have completed setting up your style sheets for desktop view.  Usage of this function will overwrite any styles you have created for the mobile style sheet you are copying to.  It is not necessary to use this function, but it can be handy as a starting point for creating your mobile styles.  Also, you may create mobile style sheets for style sheets that do not have analogous mobile style sheets by default.");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "Are you sure you want to copy");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "? All of the styles in");
@@ -440,7 +463,7 @@ define('EDIT_CSS_CHANGE_STYLE_SHEET', "Change Style Sheet");
 define('EDIT_CSS_USE_SETTINGS_BELOW', "Use Settings Below");
 define('EDIT_CSS_GO_TO', "Go to");
 define('EDIT_CSS_SORT_ALPHABETICALLY', "Sort alphabetically");
-define('EDIT_CSS_CLICK_NONE_MSG', 'Click "None" only to explicitly enforce no text decoration.');
+define('EDIT_CSS_CLICK_NONE_MSG', "Click 'None' only to explicitly enforce no text decoration.");
 define('EDIT_CSS_WHITE_SPACE', "White Space");
 define('EDIT_CSS_TABLE_LAYOUT', "Table Layout");
 define('EDIT_CSS_CURSOR', "Cursor");
@@ -452,7 +475,7 @@ define('EDIT_CSS_BOTTOM_RIGHT', "Bottom Right");
 define('EDIT_CSS_BOTTOM_LEFT', "Bottom Left");
 define('EDIT_CSS_Z_INDEX', "Z Index");
 define('EDIT_CSS_BACKGROUND_IMAGE', "Background Image");
-define('EDIT_CSS_CLICK_AUTO_MSG', 'Click "Auto" only to explicitly enforce auto margin.');
+define('EDIT_CSS_CLICK_AUTO_MSG', "Click 'Auto' only to explicitly enforce auto margin.");
 define('EDIT_CSS_REPEAT_HORIZONTALLY', "Repeat Horizontally");
 define('EDIT_CSS_REPEAT_VERTICALLY', "Repeat Vertically");
 define('EDIT_CSS_NO_REPEAT', "No Repeat");
@@ -467,6 +490,8 @@ define('EDIT_CSS_TABLE_COLUMN_GROUP', "Table Column Group");
 define('EDIT_CSS_TABLE_COLUMN', "Table Column");
 define('EDIT_CSS_TABLE_CELL', "Table Cell");
 define('EDIT_CSS_TABLE_CAPTION', "Table Caption");
+define('EDIT_CSS_FLEX', "Flex");
+define('EDIT_CSS_INLINE_FLEX', "Inline-Flex");
 define('EDIT_CSS_ALL_SCROLL', "All Scroll");
 define('EDIT_CSS_CONTEXT_MENU', "Context Menu");
 define('EDIT_CSS_COLUMN_RESIZE', "Column Resize");
@@ -507,6 +532,19 @@ define('EDIT_CSS_HIRAGANA', "Hiragana");
 define('EDIT_CSS_KATAKANA', "Katakana");
 define('EDIT_CSS_HIRAGANA_IROHA', "Hiragana Iroha");
 define('EDIT_CSS_KATAKANA_IROHA', "Katakana Iroha");
+define('EDIT_CSS_SHOW_ALL_CLASSES', "Show all classes");
+define('EDIT_CSS_FOREGROUND_OPAQUE_1', "Foreground");
+define('EDIT_CSS_FOREGROUND_OPAQUE_2', "Opaque");
+define('EDIT_CSS_CONTENT_TEXT', "Content Text");
+define('EDIT_CSS_JUSTIFY_CONTENT', "Justify Content");
+define('EDIT_CSS_FLEX_START', "Flex Start");
+define('EDIT_CSS_FLEX_END', "Flex End");
+define('EDIT_CSS_SPACE_BETWEEN', "Space Between");
+define('EDIT_CSS_SPACE_AROUND', "Space Around");
+define('EDIT_CSS_SET_DISPLAY_FLEX', "Set Display Flex");
+define('EDIT_CSS_WRAP_REVERSE', "Wrap Reverse");
+define('EDIT_CSS_ROW_REVERSE', "Row Reverse");
+define('EDIT_CSS_COLUMN_REVERSE', "Column Reverse");
 // Popup Messages:
 define('EDIT_CSS_CLICK_UPDATE_TO_COMMIT_MSG', "Click 'Update' to commit changes.");
 define('EDIT_CSS_UPDATE_COMPLETE_MSG', "Update complete");
@@ -529,6 +567,10 @@ define('EDIT_CSS_COULD_NOT_RENAME_1_ERR', "Could not rename");
 define('EDIT_CSS_COULD_NOT_RENAME_2_ERR', "to");
 define('EDIT_CSS_CANT_CREATE_ERR', "Can't create");
 define('EDIT_CSS_SELECT_PAGE_FOR_PREVIEW', "Select a page to preview your CSS changes");
+define('EDIT_CSS_DISPLAY_SET_TO_FLEX', "The display attribute has been set to 'flex'.");
+define('EDIT_CSS_ENTER_STR_MSG', "Enter the text to use as content into the Content Text input field, or leave blank to set text to blank.");
+define('EDIT_CSS_ENTER_URL_MSG', "Enter the URL into the Content Text input field.");
+define('EDIT_CSS_ENTER_ATTR_MSG', "Enter the HTML object attribite, i.e. 'href' or 'name' into the Content Text input field.");
 
 ///////////////////////// Edit CLASSES /////////////////////////
 // Buttons:
@@ -542,7 +584,7 @@ define('CLASSES_EDIT_CLASS_DESCRIPTION', "Edit Class Description");
 define('CLASSES_SET_CLASS_SORT_ORDER', "Set Class Sort Order");
 define('CLASSES_CREATE_LINK_SET', "Create Link Set");
 define('CLASSES_CLASS_DESCRIPTION', "Class / Description");
-define('CLASSES_CLASS_ID_NOTE', 'Select "Class" for . (dot) prefix or select "ID" for # prefix.');
+define('CLASSES_CLASS_ID_NOTE', "Select 'Class' for . (dot) prefix or select 'ID' for # prefix.");
 define('CLASSES_COPY_CLASS', "Copy/Rename Class");
 define('CLASSES_FROM_CLASS', "From Class");
 define('CLASSES_TO_CLASS', "To Class");
@@ -578,6 +620,8 @@ define('EDIT_HEAD_SELECT_HEADING', "Edit Head Code");
 // Buttons:
 define('MANAGE_HEAD_HEADING', "Manage Head Code");
 define('MANAGE_HEAD_ADD_HEAD_BTN', "Add Another Head Content");
+define('MANAGE_HEAD_BACK_BTN', "Back to Edit Head Code");
+define('MANAGE_HEAD_MANAGE_BTN', "Manage Custom Head Code");
 // Console Text:
 define('MANAGE_HEAD_ADD_HEAD_CONTENT', "Add Head Content");
 define('MANAGE_HEAD_ASSIGN_HEAD_CONTENT_TO_PAGE', "Assign Head Content to Page");
@@ -791,6 +835,8 @@ define('MANAGE_PAGE_ACCESS_USER_CHANGED_4_MSG', "and an email of");
 define('MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR', "Error: No data found for that user");
 define('MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR', "You must have a user table selected if you want to require login to access a page.  Please select a user table and try again.");
 define('MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR', "You must have a login page selected if you want to require login to access a page.  Please select a login page and try again. If there are no login pages in the list, you must first create a login page wich the login plugin. The name of the login page must contain 'login'.");
+define('MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR', "Table is missing user-login fields.  If you want to use this table for user access, you must first add user-login fields to this table using the 'Add User Login Fields to Table' button.");
+
 
 
 ///////////////////////// Manage Page Attributes /////////////////////////
@@ -819,6 +865,7 @@ define('MANAGE_PAGE_ATTRIBUTES_ERROR_ONLOAD_ERR', "If 'Call Body OnLoad Function
 ///////////////////////// Upload Template /////////////////////////
 // Buttons:
 define('UPLOAD_TEMPLATE_HEADING', "Upload Template");
+define('GET_MORE_TEMPLATES_BTN', "Get More Templates");
 // Console Text:
 define('UPLOAD_TEMPLATE_CONFIRM_MSG', "Are your sure you want to upload a new template? Continuing will replace your current site and the changes are irreversible.  You will be given a choice whether or not you want to keep your page content, but the theme and border area content will be replaced.");
 define('RERUN_WIZARD_RUN_WIZARD_CONFIRM_MSG', "Are your sure you want to re-run the wizard? Continuing will replace your current site and the changes are irreversible.  You will be given a choice whether or not you want to keep your page content, but the theme and border area content will be replaced.
@@ -849,6 +896,7 @@ define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES', "Delete all pages");
 define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG', "Are you sure you want to delete all of your page content?");
 define('UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG', "Uploading template, please wait...");
 define('UPLOAD_TEMPLATE_UPLOADING', "Uploading...");
+define('UPLOAD_TEMPLATE_UPLOAD_TEMPLATE_COMPLETE', "Template installation is complete.");
 
 ///////////////////////// Admin Function Select /////////////////////////
 // Buttons:
@@ -856,6 +904,7 @@ define('ADMIN_FUNCTION_SELECT_HEADING', "Manage Users &amp; Site Options");
 define('ADMIN_FUNCTION_SELECT_MANAGE_USERS_BTN', "Manage Users");
 define('ADMIN_FUNCTION_SELECT_CHANGE_SITE_OPTIONS_BTN', "Change Site Options");
 define('ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN', "Restrict Page Editing Access");
+define('ADMIN_FUNCTION_SELECT_RESTRICT_BLOG_PAGE_EDITING_ACCESS_BTN', "Restrict Blog Page Editing Access");
 define('ADMIN_FUNCTION_SELECT_GENERATE_SITE_MAP_BTN', "Generate Site Map");
 define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_BTN', "Prune Page Edit Backup Table");
 define('ADMIN_FUNCTION_SELECT_PRUNE_BACKUP_FILES_BTN', "Prune CSS, site map,<br />file edit backup, and<br />JavaScript menu backup files");
@@ -917,6 +966,7 @@ define('MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR', "There was an error savin
 ///////////////////////// Restrict Page Editing Access /////////////////////////
 // Buttons:
 define('RESTRICT_PAGE_EDITING_HEADING', "Restrict Access to Editing Pages for Restricted Users");
+define('RESTRICT_BLOG_EDITING_HEADING', "Restrict Access to Blogging for Bloggers");
 // Console Text:
 // Popup Messages:
 define('RESTRICT_PAGE_EDITING_RESTRICTIONS_SAVED_MSG', "Page restrictions have been saved.");
@@ -938,7 +988,7 @@ define('GENERATE_SITE_MAP_CANT_CREATE_ERR', "Can't create");
 // Buttons:
 define('INSTALL_PLUGIN_HEADING', "Install Plugin");
 // Console Text:
-define('INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN', "Please enter the password for the \"admin\" user account");
+define('INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN', "Please enter the password for your user account");
 define('INSTALL_PLUGIN_SELECT_PLUGIN_FROM_YOUR_COMPUTER', "Select the plugin you want to install from your computer");
 define('INSTALL_PLUGIN_INSTALLING_PLUGIN', "Installing plugin....");
 define('INSTALL_PLUGIN_WRONG_FILE_TYPE_MSG', "Only zipped files or gzipped tar files are allowed to be uploaded, i.e. 'plugin.zip' or 'plugin.tgz' or 'plugin.tar.gz'.  Please click");
@@ -983,7 +1033,7 @@ define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_2_MSG', "?");
 ///////////////////////// Options /////////////////////////
 // Strings:
 define('OPTIONS_TEMPLATE', "Template");
-define('OPTIONS_FORCE_PAGE_NAME_TO_LOWER_CASE', "Force Page Name To Lower Case");
+define('OPTIONS_FORCE_PAGE_NAME_TO_LOWER_CASE', "Force Page Name To Lowercase");
 define('OPTIONS_ENABLE_WIZARD', "Enable Wizard");
 define('OPTIONS_RUN_WIZARD_LOCAL', "Run Wizard Local (Check only if template repository and Breeze installation are on same server.)");
 define('OPTIONS_ENABLE_FILE_MANAGER_FOR_RESTRICTED_USERS', "Enable File Manager for Restricted Users");
@@ -1002,6 +1052,8 @@ define('OPTIONS_EDITOR_SOURCE_VIEW_THEME', "Editor Source View Theme");
 define('OPTIONS_BREEZE_WEBSITE_BUILDER_THEME', "Breeze Website Builder Theme");
 define('OPTIONS_LOCKOUT_CLEAR_ALL_CUSTOM_CSS_CLASSES', "Lockout Clear All Custom CSS Classes");
 define('OPTIONS_LOCKOUT_COPY_STYLE_SHEET_TO_MOBILE', "Lockout Copy Style Sheet to Mobile");
+define('OPTIONS_ENABLE_CSS_MENUS', "Enable CSS Menus");
+define('OPTIONS_ENABLE_JS_MENUS', "Enable JavaScript Menus");
 
 ////////////////////// Manage Custom Fonts /////////////////////////////////////
 // Buttons:
@@ -1068,6 +1120,53 @@ define('BACKUP_RESTORE_RESTORE_COMPLETE', "Site restoration is now complete.");
 define('BACKUP_RESTORE_DUMPING_DATABASE', "Dumping database...");
 define('BACKUP_RESTORE_ZIPPING_FILES', "Archiving files...");
 
+////////////////////// Mega Menu /////////////////////////////////////
+// Buttons:
+define('MEGA_MENU_MANAGE_BTN', "Manage Mega Menus");
+define('MEGA_MENU_EDIT_SELECT_HEADING', "Edit Mega Menus");
+define('MEGA_MENU_CREATE_HEADING', "Create Mega Menu");
+define('MEGA_MENU_BACK_BTN', "Back to Edit Menu Items");
+// Console Text:
+// Popup Messages:
+define('MEGA_MENU_PAGE_ALREADY_EXISTS_1_ERR', "Mega menu");
+define('MEGA_MENU_PAGE_ALREADY_EXISTS_2_ERR', "already exists.  Please enter a different name or edit the existing one.");
+
+////////////////////// Manage Style Sheets /////////////////////////////////////
+// Buttons:
+define('MANAGE_STYLE_SHEET_ATT_HEADING', "Manage Style Sheet Attributes");
+define('MANAGE_STYLE_SHEET_ATT_BACK_TO_EDIT_CSS_SELECT', "Back to Edit CSS Select");
+// Console Text:
+define('MANAGE_STYLE_SHEET_ATT_CHARSET', "Charset");
+define('MANAGE_STYLE_SHEET_ATT_IMPORT', "Import");
+define('MANAGE_STYLE_SHEET_ATT_MEDIA', "Media");
+define('MANAGE_STYLE_SHEET_ATT_MEDIA_TYPE', "Media Type");
+define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE', "Media Feature");
+define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE_VALUE', "Media Feature Value");
+define('MANAGE_STYLE_SHEET_ATT_ADD_STYLE_SHEET', "Add Style Sheet");
+define('MANAGE_STYLE_SHEET_ATT_DELETE_STYLE_SHEET', "Delete Style Sheet");
+define('MANAGE_STYLE_SHEET_ATT_RENAME_STYLE_SHEET', "Rename Style Sheet");
+define('MANAGE_STYLE_SHEET_ATT_NEW_NAME', "New Name");
+define('MANAGE_STYLE_SHEET_ATT_NEW_DESC', "New Description");
+define('MANAGE_STYLE_SHEET_ATT_EXCLUDE_FROM_LIST', "Exclude from default list");
+define('MANAGE_STYLE_SHEET_ATT_SHOW_CUSTOM_STYLES', "Show custom styles");
+define('MANAGE_STYLE_SHEET_ATT_SHOW_ALL', "Show all style sheets");
+define('MANAGE_STYLE_SHEET_SET_SORT_ORDER', "Set Style Sheet Sort Order");
+define('MANAGE_STYLE_SHEET_NAME_DESCRIPTION', "  	Style Sheet / Description");
+// Popup Messages:
+define('MANAGE_STYLE_SHEET_ATT_SAVE_SUCCESS_MSG', "Your style sheets attributes have been saved.");
+define('MANAGE_STYLE_SHEET_ATT_SAVE_ERROR_ERR', "There was an error saving your style sheets attributes.");
+define('MANAGE_STYLE_SHEET_ATT_ADD_SUCCESS_MSG', "Your style sheet has been saved.");
+define('MANAGE_STYLE_SHEET_ATT_ADD_SHEET_ALREADY_EXISTS_ERR', "That style sheet already exists. Please choose a different name and try again");
+define('MANAGE_STYLE_SHEET_ATT_ADD_ERROR_ERR', "There was an error adding your style sheet.");
+define('MANAGE_STYLE_SHEET_ATT_DELETE_CONFIRM_MSG', "Are you sure you want to delete the");
+define('MANAGE_STYLE_SHEET_ATT_DELETE_SUCCESS_MSG', "Your style sheet has been deleted.");
+define('MANAGE_STYLE_SHEET_ATT_DELETE_ERROR_ERR', "There was an error deleting your style sheet.");
+define('MANAGE_STYLE_SHEET_ATT_RENAME_SUCCESS_MSG', "Your style sheet has been renamed.");
+define('MANAGE_STYLE_SHEET_ATT_RENAME_ERROR_ERR', "There was an error renaming your style sheet.");
+
+////////////////////// Managing Important CSS Attributes /////////////////////////////////////
+// Buttons:
+define('IMPORTANT_HEADING', "Manage Important CSS Attributes");
 
 
 ///////////////// Standard words and phrases ///////////////////////
@@ -1154,7 +1253,7 @@ define('INITIAL_WORD', "Initial");
 define('INHERIT_WORD', "Inherit");
 define('INITIAL_LC_WORD', "initial");
 define('INHERIT_LC_WORD', "inherit");
-define('RGB_WORD', "#RRGGBB");
+define('RGB_WORD', "#RGB");
 define('TEXT_WORD', "Text");
 define('ALIGN_WORD', "Align");
 define('BACKGROUND_WORD', "Background");
@@ -1196,6 +1295,7 @@ define('X_LARGE_WORD', "x-large");
 define('XX_LARGE_WORD', "xx-large");
 define('SMALLER_WORD', "smaller");
 define('LARGER_WORD', "larger");
+define('WRAP_WORD', "Wrap");
 define('NO_WRAP_WORD', "No Wrap");
 define('PRE_WORD', "Pre");
 define('PRE_LINE_WORD', "Pre-Line");
@@ -1299,6 +1399,44 @@ define('TITLE_WORD', "Title");
 define('REFRESH_WORD', "Refresh");
 define('FOLDER_WORD', "folder");
 define('DOWNLOAD_WORD', "Download");
+define('MENU_WORD', "Menu");
+define('NOT_WORD', "Not");
+define('ONLY_WORD', "Only");
+define('ALL_WORD', "All");
+define('PRINT_WORD', "Print");
+define('SCREEN_WORD', "Screen");
+define('SPEECH_WORD', "Speech");
+define('AND_WORD', "and");
+define('DESKTOP_WORD', "Desktop");
+define('USERS_WORD', "Users");
+define('PUBLISHED_WORD', "Published");
+define('DRAFT_WORD', "Draft");
+define('CAPITALIZE_WORD', "Capitalize");
+define('UPPERCASE_WORD', "Uppercase");
+define('LOWERCASE_WORD', "Lowercase");
+define('STRING_WORD', "String");
+define('ATTRIBUTE_WORD', "Attribute");
+define('COUNTER_WORD', "Counter");
+define('TRANSITION_WORD', "Transition");
+define('PROPERTY_WORD', "Property");
+define('DURATION_WORD', "Duration");
+define('DELAY_WORD', "Delay");
+define('EASE_WORD', "Ease");
+define('LINEAR_WORD', "Linear");
+define('RADIAL_WORD', "Radial");
+define('BASIS_WORD', "Basis");
+define('GROW_WORD', "Grow");
+define('SHRINK_WORD', "Shrink");
+define('LENGTH_WORD', "Length");
+define('DIRECTION_WORD', "Direction");
+define('ROW_WORD', "Row");
+define('COLUMN_WORD', "Column");
+define('THRU_WORD', "thru");
+define('OF_WORD', "of");
+define('ANGLE_WORD', "Angle");
+define('DEGREES_WORD', "Degrees");
+define('HOVER_WORD', "Hover");
+define('DOWN_WORD', "Down");
 
 define('QUERY_READY_TO_SEND', "Query ready to send...");
 define('QUERY_SENT', "Query sent");
@@ -1338,10 +1476,40 @@ define('DELETE_USER', "Delete User");
 define('NEW_PASSWORD', "New Password");
 define('SELECT_ALL', "Select All");
 define('CLEAR_ALL', "Clear All");
+define('ADD_ALL', "Add All");
 define('TO_TRY_AGAIN', "to try again.");
 define('AND_TRY_AGAIN', "and try again.");
 define('NEW_FILE', "New File");
 define('NEW_FOLDER', "New Folder");
 define('FOLDER_NAME', "Folder Name");
 define('SHOW_BACKUP_FILES', "Show Backup Files");
+define('MENU_ITEM', "Menu Item");
+define('MIN_WIDTH', "Min Width");
+define('MAX_WIDTH', "Max Width");
+define('MIN_HEIGHT', "Min Height");
+define('MAX_HEIGHT', "Max Height");
+define('BORDER_RADIUS', "Border Radius");
+define('BLOG_PAGE', "Blog Page");
+define('TEXT_TRANSFORM', "Text Transform");
+define('OPEN_QUOTE', "Open Quote");
+define('CLOSE_QUOTE', "Close Quote");
+define('NO_OPEN_QUOTE', "No Open Quote");
+define('NO_CLOSE_QUOTE', "No Close Quote");
+define('TIMING_FUNCTION', "Timing Function");
+define('EASE_IN', "Ease In");
+define('EASE_OUT', "Ease Out");
+define('EASE_IN_OUT', "Ease In and Out");
+define('WIDTH_AND_HEIGHT', "Width and Height");
+define('SHOWING_RECORDS', "Showing records");
+define('FIRST_NAME', "First Name");
+define('LAST_NAME', "Last Name");
+define('BACKGROUND_GRADIENT', "Background Gradient");
+define('TOP_TO_BOTTOM', "Top to Bottom");
+define('BOTTOM_LEFT_TO_TOP_RIGHT', "Bottom Left to Top Right");
+define('LEFT_TO_RIGHT', "Left to Right");
+define('TOP_LEFT_TO_BOTTOM_RIGHT', "Top Left to Bottom Right");
+define('BOTTOM_TO_TOP', "Bottom to Top");
+define('TOP_RIGHT_TO_BOTTOM_LEFT', "Top Right to Bottom Left");
+define('RIGHT_TO_LEFT', "Right to Left");
+define('BOTTOM_RIGHT_TO_TOP_LEFT', "Bottom Right to Top Left");
 ?>
\ No newline at end of file
